==> trilinos_12.14.1.orig.tar.gz: Trilinos-trilinos-release-12-14-1/packages/seacas/libraries/plt/pltstd.f <==
C Copyright (C) 2009-2017 National Technology & Engineering Solutions
C of Sandia, LLC (NTESS).  Under the terms of Contract DE-NA0003525 with
C NTESS, the U.S. Government retains certain rights in this software.
C 
C Redistribution and use in source and binary forms, with or without
C modification, are permitted provided that the following conditions are
C met:
C 
C     * Redistributions of source code must retain the above copyright
C       notice, this list of conditions and the following disclaimer.
C 
C     * Redistributions in binary form must reproduce the above
C       copyright notice, this list of conditions and the following
C       disclaimer in the documentation and/or other materials provided
C       with the distribution.
C 
C     * Neither the name of NTESS nor the names of its
C       contributors may be used to endorse or promote products derived
C       from this software without specific prior written permission.
C 
C THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
C "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
C LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
C A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
C OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
C SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
C LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
C DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
C THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
C (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
C OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
C 

C $Id: pltstd.f,v 1.1 1993/07/16 16:49:32 gdsjaar Exp $ 
C $Log: pltstd.f,v $
C Revision 1.1  1993/07/16 16:49:32  gdsjaar
C Changed plt to library rather than single source file.
C 
C=======================================================================
      LOGICAL FUNCTION PLTSTD(INDX,BUFF)
      REAL DEVCAP(23)
      REAL DEFOUT(7)
      COMMON /STATUS/DEVCAP,DEFOUT
      REAL DEVP(5)
      COMMON /DEVICE/DEVP
      REAL COLP(3)
      REAL PALETT(3,16)
      COMMON /COLOR/COLP,PALETT
      REAL TEXTP(40)
      COMMON /TEXT/TEXTP
      REAL VECTP(5)
      REAL XCUR
      REAL YCUR
      COMMON /VECTRC/VECTP,XCUR,YCUR
      INTEGER IDEX(200,2)
      INTEGER NVECT(200,2)
      REAL XSIZE(200,2)
      REAL YSIZE(200,2)
      REAL X0(2300,2)
      REAL Y0(2300,2)
      REAL X1(2300,2)
      REAL Y1(2300,2)
      COMMON /FONT/IDEX,NVECT,XSIZE,YSIZE,X0,Y0,X1,Y1
      REAL GRAPHP(100)
      COMMON /GRAPH/GRAPHP
      COMMON /MAPPAR/MAPP(11)
      REAL MAPP
      COMMON /STORAG/MEMORY(1000)
      DIMENSION BUFF(*)
      CHARACTER*16 IERROR
      DATA ZZZFC/-1./,ZZZBC/-1./,ZZZIN/-1./

      PLTSTD = .TRUE.
      IF (INDX.EQ.0) THEN
         CALL PLTRSD

      ELSE IF (INDX.EQ.1) THEN
         IF (ZZZFC.EQ.BUFF(1)) THEN
            RETURN

         END IF

         ZZZFC = BUFF(1)
         J = NINT(BUFF(1))
         CALL VDSTFC(J)
         DEVP(1) = BUFF(1)

      ELSE IF (INDX.EQ.2) THEN
         IF (ZZZBC.EQ.BUFF(1)) THEN
            RETURN

         END IF

         ZZZBC = BUFF(1)
         CALL VDSTBC(IFIX(BUFF(1)))
         DEVP(2) = BUFF(1)

      ELSE IF (INDX.EQ.3) THEN
         IF (ZZZIN.EQ.BUFF(1)) THEN
            RETURN

         END IF

         ZZZIN = BUFF(1)
         CALL VDSTIN(BUFF(1)/100.)
         DEVP(3) = BUFF(1)

      ELSE
         CALL CHRIC(INDX,IERROR,L)
         CALL PLTFLU
         CALL SIORPT('PLTSTD','Illegal index '//IERROR(1:L)//'.',2)
         PLTSTD = .FALSE.
         RETURN

      END IF

      RETURN

      END

==> trilinos-16.1.0.tar.gz: Trilinos-trilinos-release-16-1-0/packages/seacas/libraries/plt/pltstd.f <==
C Copyright(C) 1999-2020 National Technology & Engineering Solutions
C of Sandia, LLC (NTESS).  Under the terms of Contract DE-NA0003525 with
C NTESS, the U.S. Government retains certain rights in this software.
C
C See packages/seacas/LICENSE for details

C=======================================================================
      LOGICAL FUNCTION PLTSTD(INDX,BUFF)
      REAL DEVCAP(23)
      REAL DEFOUT(7)
      COMMON /STATUS/DEVCAP,DEFOUT
      REAL DEVP(5)
      COMMON /DEVICE/DEVP
      REAL COLP(3)
      REAL PALETT(3,16)
      COMMON /COLOR/COLP,PALETT
      REAL TEXTP(40)
      COMMON /TEXT/TEXTP
      REAL VECTP(5)
      REAL XCUR
      REAL YCUR
      COMMON /VECTRC/VECTP,XCUR,YCUR
      INTEGER IDEX(200,2)
      INTEGER NVECT(200,2)
      REAL XSIZE(200,2)
      REAL YSIZE(200,2)
      REAL X0(2300,2)
      REAL Y0(2300,2)
      REAL X1(2300,2)
      REAL Y1(2300,2)
      COMMON /FONT/IDEX,NVECT,XSIZE,YSIZE,X0,Y0,X1,Y1
      REAL GRAPHP(100)
      COMMON /GRAPH/GRAPHP
      COMMON /MAPPAR/MAPP(11)
      REAL MAPP
      COMMON /STORAG/MEMORY(1000)
      DIMENSION BUFF(*)
      CHARACTER*16 IERROR
      DATA ZZZFC/-1./,ZZZBC/-1./,ZZZIN/-1./

      PLTSTD = .TRUE.
      IF (INDX.EQ.0) THEN
         CALL PLTRSD

      ELSE IF (INDX.EQ.1) THEN
         IF (ZZZFC.EQ.BUFF(1)) THEN
            RETURN

         END IF

         ZZZFC = BUFF(1)
         J = NINT(BUFF(1))
         CALL VDSTFC(J)
         DEVP(1) = BUFF(1)

      ELSE IF (INDX.EQ.2) THEN
         IF (ZZZBC.EQ.BUFF(1)) THEN
            RETURN

         END IF

         ZZZBC = BUFF(1)
         CALL VDSTBC(INT(BUFF(1)))
         DEVP(2) = BUFF(1)

      ELSE IF (INDX.EQ.3) THEN
         IF (ZZZIN.EQ.BUFF(1)) THEN
            RETURN

         END IF

         ZZZIN = BUFF(1)
         CALL VDSTIN(BUFF(1)/100.)
         DEVP(3) = BUFF(1)

      ELSE
         CALL CHRIC(INDX,IERROR,L)
         CALL PLTFLU
         CALL SIORPT('PLTSTD','Illegal index '//IERROR(1:L)//'.',2)
         PLTSTD = .FALSE.
         RETURN

      END IF

      RETURN

      END
